@@ -30,7 +30,6 @@ from selenium.webdriver.chrome.options import Options
 from mftoolbox.constants import Header
 from selenium.webdriver import Chrome
 import os
-import subprocess
 import time
 
 class Browser(webdriver.Chrome):
@@ -42,69 +41,6 @@ class Browser(webdriver.Chrome):
     clean (True default): limpa o cache da janela
     """
 
-    def clear_cache(self):
-        # opening clear browse data page
-        self.get('chrome://settings/clearBrowserData')
-        # find time range dropdown. Full xpath:
-        # /html/body/# settings-ui//div[2]/settings-main//settings-basic-page//div[1]/settings-section[4]/settings-privacy-page
-        # //# settings-clear-browsing-data-dialog//cr-dialog[1]/div[3]/iron-pages/div[2]/div/settings-dropdown-menu//select'
-        try:
-            self.__root1 = self.find_element_by_tag_name("settings-ui")
-            self.__shadow_root1 = self.__expand_shadow_element(self, self.__root1)
-            self.__root2 = self.__shadow_root1.find_element_by_css_selector("settings-main#main")
-            self.__shadow_root2 = self.__expand_shadow_element(self, self.__root2)
-            self.__root3 = self.__shadow_root2.find_element_by_css_selector("settings-basic-page[role='main']")
-            self.__shadow_root3 = self.__expand_shadow_element(self, self.__root3)
-            self.__webelement1 = self.__shadow_root3.find_element_by_css_selector("settings-section[page-title='Privacy and security']")
-            self.__root4 = self.__webelement1.find_element_by_css_selector('settings-privacy-page')
-            self.__shadow_root4 = self.__expand_shadow_element(self, self.__root4)
-            time.sleep(1)
-            self.__root5 = self.__shadow_root4.find_element_by_css_selector('settings-clear-browsing-data-dialog')
-            self.__shadow_root5 = self.__expand_shadow_element(self, self.__root5)
-            self.__root6 = self.__shadow_root5.find_element_by_id('clearBrowsingDataDialog')
-            self.__webelement2 = self.__root6.find_element_by_id('clearFromBasic')
-            self.__shadow_root6 = self.__expand_shadow_element(self, self.__webelement2)
-            self.__dropdown = Select(self.__shadow_root6.find_element_by_id('dropdownMenu'))
-            #select option all time
-            self.__dropdown.select_by_visible_text('All time')
-            """
-            #wait for button Clear Data Button to appear
-            try:
-                while not self.__root6.find_element_by_id('clearBrowsingDataConfirm'):
-                    pass
-            except exceptions.StaleElementReferenceException:
-                raise Sair
-            """
-           # click button
-            self.__button = self.__root6.find_element_by_id('clearBrowsingDataConfirm')
-            self.__button.click()
-            # wait until button disapears
-            try:
-                while self.__button.is_displayed():
-                    pass
-            except exceptions.StaleElementReferenceException:
-                if self.current_url == 'chrome://settings/':
-                    pass
-                else:
-                    raise Sair
-
-        except Exception as e:
-            if e.args[0] == 'name \'Sair\' is not defined':
-                pass
-            else:
-                raise NameError('Ocorreu um problema')
-
-
-    def unhide(self):
-        self.set_window_position(0, 0)
-
-    def hide(self):
-        self.set_window_position(10000, 10000)
-
-    def get_focus(self):
-        __currentWindow = self.getWindowHandle()
-        self.switchTo().window(currentWindow)
-
     @classmethod
     def __expand_shadow_element(self, __browser, element):
         __shadow_root = __browser.execute_script('return arguments[0].shadowRoot', element)
@@ -113,7 +49,12 @@ class Browser(webdriver.Chrome):
 
 
 
-    def __init__(self, hide=True, clean=True, **kwargs):
+    session_id = ''
+    command_executor = ''
+    error_handler = ''
+    w3c=False
+
+    def __init__(self, hide=True, clean=True, pictures=False, **kwargs):
 
         #setting up controls
         if clean not in [True,False]:
@@ -127,10 +68,6 @@ class Browser(webdriver.Chrome):
 
         if self.__hide and not self.__clean:
             self.__options.add_argument("headless")
-        try:
-            __pictures = kwargs['pictures']
-        except:
-            __pictures = False
         try:
             kill_chromedrivers = kwargs['kill']
         except:
@@ -140,29 +77,24 @@ class Browser(webdriver.Chrome):
             for linha in tabela:
                 if linha.find('chromedriver.exe') != -1:
                     try:
-                        subprocess.Popen("taskkill /f /im  chromedriver.exe",stdout = subprocess.PIPE,stderr = subprocess.PIPE)
+                        os.system("taskkill /f /im  chromedriver.exe")
                     except:
                         pass
-            # setting up the browser
+
+        # setting up the browser
         __caps = DesiredCapabilities().CHROME
         __caps["pageLoadStrategy"] = "eager"
         # noinspection SpellCheckingInspection
         __options = webdriver.ChromeOptions()
-        if not __pictures:
+        if not pictures:
             __chrome_preferences = {'profile.managed_default_content_settings.images': 2}
             # noinspection SpellCheckingInspection
             __options.add_experimental_option("prefs", __chrome_preferences)
-        __options.add_argument("disable-infobars")
+            __options.add_argument("disable-infobars")
 
-        session_id = ''
-        command_executor = ''
-        error_handler = ''
-        w3c = False
         # noinspection SpellCheckingInspection
-        Browser = webdriver.Chrome(options=__options, service_args=['--silent'], desired_capabilities=__caps)
+        Browser = webdriver.Chrome(options=self.__options, service_args=['--silent'], desired_capabilities=self.__caps)
         Browser.header_overrides = Header
-        self.w3c = Browser.w3c
-        self.service = Browser.service
         self.session_id = Browser.session_id
         self.command_executor = Browser.command_executor
         self.error_handler = Browser.error_handler
